@@ -44,7 +44,7 @@ def get_user_api_token(logger):
 
 
 class SafetyCulture:
-    def __init__(self, api_token):
+    def __init__(self, api_token, proxy_settings=None, certificate_settings=None):
         self.current_dir = os.getcwd()
         self.log_dir = self.current_dir + '/log/'
         self.api_url = 'https://api.safetyculture.io/'
@@ -54,7 +54,22 @@ class SafetyCulture:
         self.get_my_groups_url = self.api_url + 'share/connections'
         self.all_groups_url = self.api_url + 'groups'
         self.add_users_url = self.api_url + 'users'
-
+        if proxy_settings is not None:
+            self.proxy = {
+                "http": proxy_settings['http'],
+                "https": proxy_settings['https']
+            }
+        else:
+            self.proxy = None
+        if certificate_settings is not None:
+            if len(certificate_settings) == 2:
+                certs = []
+                for item in certificate_settings:
+                    certs.append(item)
+                certs = tuple(certs)
+                self.certs = certs
+        else:
+            self.certs = None
         self.create_directory_if_not_exists(self.log_dir)
         self.configure_logging()
         logger = logging.getLogger('sp_logger')
@@ -78,22 +93,48 @@ class SafetyCulture:
             sys.exit(1)
 
     def authenticated_request_get(self, url):
-        return requests.get(url, headers=self.custom_http_headers)
+        if self.proxy is not None:
+            if self.certs is not None:
+                return requests.get(url, headers=self.custom_http_headers, proxies=self.proxy, certs=self.certs)
+            else:
+                return requests.get(url, headers=self.custom_http_headers, proxies=self.proxy)
+        else:
+            return requests.get(url, headers=self.custom_http_headers)
 
     def authenticated_request_post(self, url, data):
         self.custom_http_headers['content-type'] = 'application/json'
-        response = requests.post(url, data, headers=self.custom_http_headers)
+        if self.proxy is not None:
+            if self.certs is not None:
+                response = requests.post(url, data, headers=self.custom_http_headers, proxies=self.proxy,
+                                         certs=self.certs)
+            else:
+                response = requests.post(url, data, headers=self.custom_http_headers, proxies=self.proxy)
+        else:
+            response = requests.post(url, data, headers=self.custom_http_headers)
         del self.custom_http_headers['content-type']
         return response
 
     def authenticated_request_put(self, url, data):
         self.custom_http_headers['content-type'] = 'application/json'
-        response = requests.put(url, data, headers=self.custom_http_headers)
+        if self.proxy is not None:
+            if self.certs is not None:
+                response = requests.put(url, data, headers=self.custom_http_headers, proxies=self.proxy,
+                                        certs=self.certs)
+            else:
+                response = requests.put(url, data, headers=self.custom_http_headers, proxies=self.proxy)
+        else:
+            response = requests.put(url, data, headers=self.custom_http_headers)
         del self.custom_http_headers['content-type']
         return response
 
     def authenticated_request_delete(self, url):
-        return requests.delete(url, headers=self.custom_http_headers)
+        if self.proxy is not None:
+            if self.certs is not None:
+                return requests.delete(url, headers=self.custom_http_headers, proxies=self.proxy, certs=self.certs)
+            else:
+                return requests.delete(url, headers=self.custom_http_headers, proxies=self.proxy)
+        else:
+            return requests.delete(url, headers=self.custom_http_headers)
 
     @staticmethod
     def parse_json(json_to_parse):
@@ -171,7 +212,7 @@ class SafetyCulture:
         last_modified = modified_after if modified_after is not None else '2000-01-01T00:00:00.000Z'
 
         search_url = self.audit_url + 'search?field=audit_id&field=modified_at&order=asc&modified_after=' \
-            + last_modified
+                     + last_modified
         log_string = '\nInitiating audit_discovery with the parameters: ' + '\n'
         log_string += 'template_id    = ' + str(template_id) + '\n'
         log_string += 'modified_after = ' + str(last_modified) + '\n'
@@ -186,7 +227,7 @@ class SafetyCulture:
                     search_url += '&template=' + specific_id
             else:
                 search_url += '&template=' + template_id[0]
-                
+
         if archived is True:
             search_url += '&archived=true'
         if archived is False:
@@ -253,7 +294,7 @@ class SafetyCulture:
         :return:                   export job ID obtained from API
         """
         export_url = self.audit_url + audit_id + '/report'
-        if export_format == 'docx': # convert old command line format
+        if export_format == 'docx':  # convert old command line format
             export_format = 'WORD'
         export_data = {'format': export_format.upper()}
 
@@ -398,7 +439,8 @@ class SafetyCulture:
         )
         result = self.parse_json(response.content) if response.status_code == requests.codes.ok else None
         self.log_http_status(response.status_code, 'GET actions')
-        if result is None or None in [result.get('count'), result.get('offset'), result.get('total'), result.get('actions')]:
+        if result is None or None in [result.get('count'), result.get('offset'), result.get('total'),
+                                      result.get('actions')]:
             return None
         return self.get_page_of_actions(logger, date_modified, result, offset, page_length)
 
@@ -414,7 +456,8 @@ class SafetyCulture:
         :return: Array of action objects
         """
         if previous_page['count'] + previous_page['offset'] < previous_page['total']:
-            logger.info('Paging Actions. Offset: ' + str(offset + page_length) + '. Total: ' + str(previous_page['total']))
+            logger.info(
+                'Paging Actions. Offset: ' + str(offset + page_length) + '. Total: ' + str(previous_page['total']))
             next_page = self.get_audit_actions(date_modified, offset + page_length)
             if next_page is None:
                 return None
